@@ -240,7 +240,7 @@ static Word16 Chebps(Word16 x,
     t0 += (Word32) * (p_f) << 13;
 
 
-    if ((UWord32)(t0 - 0xfe000000L) < (UWord32)0x03ffffffL)
+    if ((UWord32)(t0 + 33554432) < 67108863)
     {
         cheb = (Word16)(t0 >> 10);
     }
