@@ -31,26 +31,27 @@ terms listed above has been obtained from the copyright holder.
 
 
 
- Filename: d4_17pf.cpp
- Functions: decode_4i40_17bits
+ Filename: d2_9pf.cpp
+ Functions: decode_2i40_9bits
 
 ------------------------------------------------------------------------------
  MODULE DESCRIPTION
 
 
- FUNCTION:  decode_4i40_17bits (decod_ACELP())
+ FUNCTION:  decode_2i40_9bits (decod_ACELP())
 
  PURPOSE:   Algebraic codebook decoder. For details about the encoding see
-            c4_17pf.c
+            c2_9pf.c
 */
 
 /*----------------------------------------------------------------------------
 ; INCLUDES
 ----------------------------------------------------------------------------*/
+#include "d2_9pf.h"
 #include "typedef.h"
 #include "basic_op.h"
 #include "cnst.h"
-#include "d4_17pf.h"
+
 
 /*--------------------------------------------------------------------------*/
 #ifdef __cplusplus
@@ -68,7 +69,7 @@ extern "C"
     ; Include all pre-processor statements here. Include conditional
     ; compile variables also.
     ----------------------------------------------------------------------------*/
-#define NB_PULSE 4           /* number of pulses  */
+#define NB_PULSE  2
 
 
     /*----------------------------------------------------------------------------
@@ -81,11 +82,6 @@ extern "C"
     ; Variable declaration - defined here and used outside this module
     ----------------------------------------------------------------------------*/
 
-    /*----------------------------------------------------------------------------
-    ; EXTERNAL GLOBAL STORE/BUFFER/POINTER REFERENCES
-    ; Declare variables used in this module but defined elsewhere
-    ----------------------------------------------------------------------------*/
-
     /*--------------------------------------------------------------------------*/
 #ifdef __cplusplus
 }
@@ -93,16 +89,17 @@ extern "C"
 
 /*
 ------------------------------------------------------------------------------
- FUNCTION NAME: decode_4i40_17bits
+ FUNCTION NAME: decode_2i40_11bits
 ------------------------------------------------------------------------------
  INPUT AND OUTPUT DEFINITIONS
 
  Inputs:
-    sign  -- Word16 -- signs of 3 pulses.
-    index -- Word16 -- Positions of the 3 pulses.
+    sign  -- Word16 -- signs of 2 pulses.
+    index -- Word16 -- Positions of the 2 pulses.
 
  Outputs:
     cod[] -- array of type Word16 -- algebraic (fixed) codebook excitation
+    pOverflow = pointer to overflow flag
 
  Returns:
     None
@@ -125,7 +122,7 @@ extern "C"
 ------------------------------------------------------------------------------
  REFERENCES
 
- d4_17pf.c, UMTS GSM AMR speech codec, R99 - Version 3.2.0, March 2, 2001
+ d2_9pf.c, UMTS GSM AMR speech codec, R99 - Version 3.2.0, March 2, 2001
 
 ------------------------------------------------------------------------------
  PSEUDO-CODE
@@ -138,75 +135,53 @@ extern "C"
 ------------------------------------------------------------------------------
 */
 
-void decode_4i40_17bits(
-    Word16 sign,   /* i : signs of 4 pulses.                       */
-    Word16 index,  /* i : Positions of the 4 pulses.               */
-    const Word16* dgray_ptr, /* i : Pointer to read-only table         */
-    Word16 cod[]   /* o : algebraic (fixed) codebook excitation    */
+void decode_2i40_9bits(
+    Word16 subNr,  /* i : subframe number                          */
+    Word16 sign,   /* i : signs of 2 pulses.                       */
+    Word16 index,  /* i : Positions of the 2 pulses.               */
+    const Word16* startPos_ptr, /*  i: ptr to read only table          */
+    Word16 cod[],  /* o : algebraic (fixed) codebook excitation    */
+    Flag  *pOverflow  /* o : Flag set when overflow occurs         */
 )
 {
     Word16 i;
     Word16 j;
+    Word16 k;
 
     Word16 pos[NB_PULSE];
 
-    /* Index is a 13-bit value.  3 bits each correspond to the
-     * positions 0-2, with 4 bits allocated for position 3.
-     *
-     *
-     * [][][][] [][][] [][][] [][][]
-     *    |       |      |     |
-     *    |       |      |     |
-     *   pos3    pos2   pos1  pos0
-     */
-
     /* Decode the positions */
+    /* table bit  is the MSB */
 
-    i = index & 0x7;
+    j = (Word16)(index & 64);
 
-    i = dgray_ptr[i];
+    j >>= 3;
 
-    pos[0] = i * 5; /* pos0 =i*5 */
+    i = index & 7;
+
+    k =
+        shl(
+            subNr,
+            1,
+            pOverflow);
+
+    k += j;
+
+    /* pos0 =i*5+startPos_ptr[j*8+subNr*2] */
+    pos[0] = i * 5 + startPos_ptr[k++];
 
 
     index >>= 3;
 
-    i = index & 0x7;
+    i = index & 7;
 
-    i = dgray_ptr[i];
-
-    pos[1] = i * 5 + 1;  /* pos1 =i*5+1 */
-
-
-
-    index >>= 3;
-
-    i = index & 0x7;
-
-    i = dgray_ptr[i];
-
-    pos[2] = i * 5 + 2; /* pos2 =i*5+2 */
-
-
-
-
-
-    index >>= 3;
-
-    j = index & 0x1;
-
-    index >>= 1;
-
-    i = index & 0x7;
-
-    i = dgray_ptr[i];
-
-    pos[3] = i * 5 + 3 + j; /* pos3 =i*5+3+j */
+    /* pos1 =i*5+startPos_ptr[j*8+subNr*2 + 1] */
+    pos[1] = i * 5 + startPos_ptr[k];
 
 
     /* decode the signs  and build the codeword */
 
-    for (i = 0; i < L_SUBFR; i++)
+    for (i = L_SUBFR - 1; i >= 0; i--)
     {
         cod[i] = 0;
     }
